@@ -12,7 +12,7 @@
 # language governing permissions and limitations under the License.
 
 
-__version__ = "0.5.2"
+__version__ = "0.6.0"
 
 from awscrt.io import ClientBootstrap, DefaultHostResolver, EventLoopGroup
 
@@ -24,4 +24,7 @@ class AWSCRTEventLoop:
     def _initialize_default_loop(self):
         event_loop_group = EventLoopGroup(1)
         host_resolver = DefaultHostResolver(event_loop_group)
-        return ClientBootstrap(event_loop_group, host_resolver,)
+        return ClientBootstrap(
+            event_loop_group,
+            host_resolver,
+        )
