@@ -13,15 +13,13 @@
 
 
 from urllib.parse import urlsplit
-from typing import Dict, Union
+from typing import Dict
 
 from amazon_transcribe import __version__ as version
 from amazon_transcribe.exceptions import ValidationException
 
-HEADER_VALUE = Union[int, None, str]
 
-
-def _add_required_headers(endpoint: str, headers: Dict[str, HEADER_VALUE]):
+def _add_required_headers(endpoint: str, headers: Dict[str, str]):
     urlparts = urlsplit(endpoint)
     if not urlparts.hostname:
         raise ValidationException(
@@ -33,3 +31,10 @@ def _add_required_headers(endpoint: str, headers: Dict[str, HEADER_VALUE]):
             "host": urlparts.hostname,
         }
     )
+
+
+def ensure_boolean(val):
+    if isinstance(val, bool):
+        return val
+    else:
+        return val.lower() == "true"
